@@ -2,34 +2,31 @@
 use strict;
 use warnings;
 
-my $oDump;
-my $target = shift || die("Specify target\n");
-
 use Net::Write::Layer2;
 use Net::Frame::Device;
 use Net::Frame::Simple;
-use Net::Frame::Dump::Online;
+use Net::Frame::Dump;
 
 use Net::Frame::ETH qw(:consts);
 use Net::Frame::ARP;
 
-my $oDevice = Net::Frame::Device->new(target => $target);
+my $oDevice = Net::Frame::Device->new(target => $ARGV[0]);
 
 my $eth = Net::Frame::ETH->new(
    src  => $oDevice->mac,
-   type => NF_ETH_TYPE_ARP,
+   type => NP_ETH_TYPE_ARP,
 );
 my $arp = Net::Frame::ARP->new(
    src   => $oDevice->mac,
    srcIp => $oDevice->ip,
-   dstIp => $target,
+   dstIp => $ARGV[0],
 );
 
 my $oWrite = Net::Write::Layer2->new(
    dev => $oDevice->dev,
 );
 
-$oDump = Net::Frame::Dump::Online->new(
+my $oDump = Net::Frame::Dump->new(
    dev => $oDevice->dev,
 );
 $oDump->start;
@@ -48,4 +45,5 @@ until ($oDump->timeout) {
    }
 }
 
-END { $oDump && $oDump->isRunning && $oDump->stop }
+$oDump->stop;
+$oDump->clean;
