@@ -1,5 +1,5 @@
 #
-# $Id: PPP.pm,v 1.5 2006/12/03 16:07:35 gomor Exp $
+# $Id: PPP.pm,v 1.6 2006/12/06 21:19:40 gomor Exp $
 #
 package Net::Frame::PPP;
 use strict;
@@ -101,14 +101,6 @@ sub print {
       $self->[$__address], $self->[$__control], $self->[$__protocol];
 }
 
-#
-# Helpers
-#
-
-sub _isProtocol      { shift->[$__protocol] == shift()            }
-sub isProtocolIpv4   { shift->_isProtocol(NP_PPP_PROTOCOL_IPv4)   }
-sub isProtocolPpplcp { shift->_isProtocol(NP_PPP_PROTOCOL_PPPLCP) }
-
 1;
 
 __END__
@@ -169,11 +161,11 @@ Packs all attributes into a raw format, in order to inject to network. Returns 1
 
 Unpacks raw data from network and stores attributes into the object. Returns 1 on success, undef otherwise.
 
-=item B<isProtocolIpv4>
+=item B<encapsulate>
 
-=item B<isProtocolPpplcp>
+=item B<getLength>
 
-Return 1 when encpasulated layer is of respective type. 0 otherwise.
+=item B<print>
 
 =back
 
